@@ -10,18 +10,35 @@
 #include "soup-socket.h"
 #include "soup-message-headers.h"
 
-char *uri_decoded_copy (const char *str, int length, int *decoded_length);
+char *soup_uri_decoded_copy (const char *str, int length, int *decoded_length);
 char *soup_uri_to_string_internal (SoupURI *uri, gboolean just_path_and_query,
 				   gboolean force_port);
 gboolean soup_uri_is_http (SoupURI *uri, char **aliases);
 gboolean soup_uri_is_https (SoupURI *uri, char **aliases);
 
-guint soup_socket_handshake_sync  (SoupSocket         *sock,
-				   GCancellable       *cancellable);
-void  soup_socket_handshake_async (SoupSocket         *sock,
-				   GCancellable       *cancellable,
-				   SoupSocketCallback  callback,
-				   gpointer            user_data);
+gboolean soup_socket_connect_sync_internal   (SoupSocket          *sock,
+					      GCancellable        *cancellable,
+					      GError             **error);
+void     soup_socket_connect_async_internal  (SoupSocket          *sock,
+					      GCancellable        *cancellable,
+					      GAsyncReadyCallback  callback,
+					      gpointer             user_data);
+gboolean soup_socket_connect_finish_internal (SoupSocket          *sock,
+					      GAsyncResult        *result,
+					      GError             **error);
+
+gboolean soup_socket_handshake_sync   (SoupSocket           *sock,
+				       const char           *host,
+				       GCancellable         *cancellable,
+				       GError              **error);
+void     soup_socket_handshake_async  (SoupSocket           *sock,
+				       const char           *host,
+				       GCancellable         *cancellable,
+				       GAsyncReadyCallback   callback,
+				       gpointer              user_data);
+gboolean soup_socket_handshake_finish (SoupSocket           *sock,
+				       GAsyncResult         *result,
+				       GError              **error);
 
 GSocket   *soup_socket_get_gsocket    (SoupSocket *sock);
 GIOStream *soup_socket_get_connection (SoupSocket *sock);
