@@ -788,7 +788,8 @@ soup_server_get_port (SoupServer *server)
  *
  * In order for a server to run https, you must set the
  * %SOUP_SERVER_SSL_CERT_FILE and %SOUP_SERVER_SSL_KEY_FILE properties
- * to provide it with an SSL certificate to use.
+ * or %SOUP_SERVER_TLS_CERTIFICATE property to provide it with an SSL
+ * certificate to use.
  *
  * Return value: %TRUE if @server is serving https.
  **/
@@ -800,7 +801,7 @@ soup_server_is_https (SoupServer *server)
 	g_return_val_if_fail (SOUP_IS_SERVER (server), 0);
 	priv = SOUP_SERVER_GET_PRIVATE (server);
 
-	return (priv->ssl_cert_file && priv->ssl_key_file);
+	return priv->ssl_cert != NULL;
 }
 
 /**
@@ -1550,6 +1551,10 @@ soup_server_remove_auth_domain (SoupServer *server, SoupAuthDomain *auth_domain)
  * Pauses I/O on @msg. This can be used when you need to return from
  * the server handler without having the full response ready yet. Use
  * soup_server_unpause_message() to resume I/O.
+ *
+ * This must only be called on #SoupMessages which were created by the
+ * #SoupServer and are currently doing I/O, such as those passed into a
+ * #SoupServerCallback or emitted in a #SoupServer::request-read signal.
  **/
 void
 soup_server_pause_message (SoupServer *server,
@@ -1571,6 +1576,10 @@ soup_server_pause_message (SoupServer *server,
  * chunked response.
  *
  * I/O won't actually resume until you return to the main loop.
+ *
+ * This must only be called on #SoupMessages which were created by the
+ * #SoupServer and are currently doing I/O, such as those passed into a
+ * #SoupServerCallback or emitted in a #SoupServer::request-read signal.
  **/
 void
 soup_server_unpause_message (SoupServer *server,
