@@ -202,7 +202,7 @@ do_priority_tests (gconstpointer data)
 		  SOUP_MESSAGE_PRIORITY_HIGH,
 		  SOUP_MESSAGE_PRIORITY_NORMAL };
 
-	debug_printf (1, "\nSoupSessionAsync\n");
+	g_test_bug ("696277");
 
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
 	g_object_set (session, "max-conns", 1, NULL);
@@ -263,7 +263,7 @@ do_property_tests (void)
 	GTlsDatabase *tlsdb, *default_tlsdb;
 	SoupURI *uri;
 
-	debug_printf (1, "\nTesting session init properties\n");
+	g_test_bug ("708696");
 
 	default_proxy_resolver = g_proxy_resolver_get_default ();
 	default_tlsdb = g_tls_backend_get_default_database (g_tls_backend_get_default ());
