@@ -38,7 +38,7 @@ static GOptionEntry debug_entry[] = {
 	{ "debug", 'd', G_OPTION_FLAG_NO_ARG,
 	  G_OPTION_ARG_CALLBACK, increment_debug_level,
 	  "Enable (or increase) test-specific debugging", NULL },
-	{ "http-debug", 'h', G_OPTION_FLAG_NO_ARG,
+	{ "http-debug", 'H', G_OPTION_FLAG_NO_ARG,
 	  G_OPTION_ARG_CALLBACK, increment_http_debug_level,
 	  "Enable (or increase) HTTP-level debugging", NULL },
 	{ NULL }
@@ -76,6 +76,7 @@ test_init (int argc, char **argv, GOptionEntry *entries)
 
 	g_test_init (&argc, &argv, NULL);
 	g_test_set_nonfatal_assertions ();
+	g_test_bug_base ("https://bugzilla.gnome.org/");
 
 	opts = g_option_context_new (NULL);
 	g_option_context_add_main_entries (opts, debug_entry, NULL);
